@@ -5,6 +5,7 @@ use 5.010;
 
 # PODNAME: pwgen-xkcd.pl
 # ABSTRACT: Generate a xkcd-style password
+our $VERSION = '1.009'; # VERSION
 
 use CtrlO::Crypt::XkcdPassword;
 use Getopt::Long;
@@ -39,7 +40,7 @@ pwgen-xkcd.pl - Generate a xkcd-style password
 
 =head1 VERSION
 
-version 1.008
+version 1.009
 
 =head1 USAGE
 
@@ -56,11 +57,11 @@ See C<perldoc CtrlO::Crypt::XkcdPassword> for even more info.
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 - 2019 by Thomas Klausner.
+This software is copyright (c) 2018 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
